@@ -22,7 +22,7 @@ import dbus.service
 import dbus.mainloop.qt
 import pickle
 
-__version__ = '0.0.20'
+__version__ = '0.0.21'
 
 #Here is the installation of the hook. Each time a untrapped/unmanaged exception will
 #happen my_excepthook will be called.
@@ -88,7 +88,7 @@ class KhweeteurNotification(QObject):
     def info(self,message):
         self.iface.SystemNoteInfoprint('Khweeteur : '+message)
         
-    def notify(self,title,message,category='im.received',icon='khweeteur_32',count=1):
+    def notify(self,title,message,category='im.received',icon='khweeteur',count=1):
         self.m_id = self.iface.Notify('Khweeteur',
                           self.m_id,
                           icon,
@@ -102,7 +102,7 @@ class KhweeteurNotification(QObject):
                           -1
                           )
                           
-    def notify_search(self,keyword,title,message,category='im.received',icon='khweeteur_32',count=1):
+    def notify_search(self,keyword,title,message,category='im.received',icon='khweeteur',count=1):
         self.m_id = self.iface.Notify('Khweeteur',
                           self.m_id,
                           icon,
@@ -115,6 +115,72 @@ class KhweeteurNotification(QObject):
                           'count':count},
                           -1
                           )
+class KhweeteurActionWorker(QThread):
+
+    def __init__(self, parent = None, action=None, data=None, data2=None, data3=None):
+        QThread.__init__(self, parent)
+        self.settings = QSettings()
+        self.action = action
+        self.data = data
+        self.tb_text_replyid = data2
+        self.tb_text_replytext = data3
+
+    def run(self):
+        if self.action=='tweet':
+            self.tweet()
+        elif self.action=='retweet':
+            self.retweet()
+
+    def tweet(self):
+        try:
+                status_text = self.data
+                if status_text.startswith(self.tb_text_replytext):
+                    self.tb_text_replyid = 0
+                    
+                if self.settings.value("twitter_access_token_key").toString()!='':     
+                    api = twitter.Api(
+                                      username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
+                                      access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
+                                      access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+                    api.SetUserAgent('Khweeteur/%s' % (__version__))
+                    if self.settings.value('useSerialization').toBool():
+                        status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
+                    else:
+                        status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
+#                    self.notifications.info('Tweet send to Twitter')
+                    self.emit(SIGNAL("info(PyQt_PyObject)"),'Tweet send to Twitter')
+
+                if self.settings.value("identica_access_token_key").toString()!='':     
+                    api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
+                                      password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
+                                      access_token_key=str(self.settings.value("identica_access_token_key").toString()),
+                                      access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
+                    api.SetUserAgent('Khweeteur/%s' % (__version__))
+                    if self.settings.value('useSerialization').toBool():
+                        status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
+                    else:
+                        status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
+#                    self.notifications.info('Tweet send to Identica')
+                    self.emit(SIGNAL("info(PyQt_PyObject)"),'Tweet send to Identica')
+                                        
+                self.emit(SIGNAL("tweetSent()"))
+
+#                self.tb_text.setText('')
+#                self.tb_text_replyid = 0
+#                self.tb_text_replytext = ''
+        except (twitter.TwitterError,StandardError),e:
+            import traceback
+            print traceback.print_exc()
+            print traceback.print_stack()
+            if type(e)==twitter.TwitterError:
+#                self.notifications.warn('Send tweet failed : '+(e.message))
+                self.emit(SIGNAL("warn(PyQt_PyObject)"),e.message)
+                print e.message
+            else:
+#                self.notifications.warn('Send tweet failed : '+str(e))
+                self.emit(SIGNAL("warn(PyQt_PyObject)"),str(e))
+                print e 
+
                           
 class KhweeteurWorker(QThread):
 
@@ -128,6 +194,7 @@ class KhweeteurWorker(QThread):
         if self.search_keyword==None:
             self.refresh()
         else:
+            print 'Worker Refresh search : '+self.search_keyword 
             self.refresh_search()
 
     def testCacheFolders(self):
@@ -297,7 +364,7 @@ class KhweetsModel(QAbstractListModel):
         self.display_timestamp = False
         self.display_avatar = True
 
-        self.keyword = None
+        self.keyword = keyword
 
     def GetRelativeCreatedAt(self,timestamp):
         '''Get a human redable string representing the posting time
@@ -344,6 +411,7 @@ class KhweetsModel(QAbstractListModel):
         
     def addStatuses(self,listVariant):
         GetRelativeCreatedAt = self.GetRelativeCreatedAt
+        print 'Debug addstatuses count:',len(listVariant)
         for _,variant in listVariant:
             try:
                 if all(item[1]!=variant.id for item in self._items):
@@ -355,13 +423,14 @@ class KhweetsModel(QAbstractListModel):
                              variant.text,
                              variant.user.profile_image_url,
                              GetRelativeCreatedAt(variant.created_at_in_seconds),))
-                    if variant.user.screen_name!=None:
-                        try:
-                            if variant.user.profile_image_url[4]!=None:
-                                pix = QPixmap(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url.replace('/','_')))).scaled(50,50)
-                                self._avatars[variant.user.profile_image_url] = QIcon(pix)
-                        except StandardError, err:
-                            print 'error on loading avatar :',err
+
+                        if variant.user.screen_name!=None:
+                            try:
+                                if variant.user.profile_image_url[4]!=None:
+                                    pix = QPixmap(os.path.join(AVATAR_CACHE_FOLDER,os.path.basename(variant.user.profile_image_url.replace('/','_')))).scaled(50,50)
+                                    self._avatars[variant.user.profile_image_url] = QIcon(pix)
+                            except StandardError, err:
+                                print 'error on loading avatar :',err
                     else:
                         self._items.insert(0,
                              (variant.created_at_in_seconds,
@@ -482,6 +551,7 @@ class KhweetsView(QListView):
         self.setResizeMode(QListView.Adjust)
         self.setViewMode(QListView.ListMode)
         self.setHorizontalScrollBarPolicy(Qt.ScrollBarAlwaysOff)
+#        self.setAlternatingRowColors(True)
 
 
 class KhweeteurAbout(QMainWindow):
@@ -871,6 +941,7 @@ class KhweeteurWin(QMainWindow):
         self.tb_text_replyid = self.tweetsModel._items[index.row()][1]
         self.tb_text_replytext = '@'+user+' '
         self.tb_text.setText('@'+user+' ')
+        print 'DEbug tweet id :',self.tb_text_replyid 
 
     def open_url(self):
         import re
@@ -1007,50 +1078,68 @@ class KhweeteurWin(QMainWindow):
                         self.notifications.warn('Retweet to identi.ca failed : '+str(e))
                         print e                 
 
-                                              
-    def tweet(self):
-        try:
-                status_text = unicode(self.tb_text.text()).encode('UTF-8')
-                if status_text.startswith(self.tb_text_replytext):
-                    self.tb_text_replyid = 0
-                    
-                if self.settings.value("twitter_access_token_key").toString()!='':     
-                    api = twitter.Api(
-                                      username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
-                                      access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
-                                      access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
-                    api.SetUserAgent('Khweeteur/%s' % (__version__))
-                    if self.settings.value('useSerialization').toBool():
-                        status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
-                    else:
-                        status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
-                    self.notifications.info('Tweet send to Twitter')
+    def tweetSent(self):
+        self.tb_text.setText('')
+        self.tb_text_replyid = 0
+        self.tb_text_replytext = ''
 
-                if self.settings.value("identica_access_token_key").toString()!='':     
-                    api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
-                                      password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
-                                      access_token_key=str(self.settings.value("identica_access_token_key").toString()),
-                                      access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
-                    api.SetUserAgent('Khweeteur/%s' % (__version__))
-                    if self.settings.value('useSerialization').toBool():
-                        status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
-                    else:
-                        status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
-                    self.notifications.info('Tweet send to Identica')
-                    
-                self.tb_text.setText('')
-                self.tb_text_replyid = 0
-                self.tb_text_replytext = ''
-        except (twitter.TwitterError,StandardError),e:
-            import traceback
-            print traceback.print_exc()
-            print traceback.print_stack()
-            if type(e)==twitter.TwitterError:
-                self.notifications.warn('Send tweet failed : '+(e.message))
-                print e.message
-            else:
-                self.notifications.warn('Send tweet failed : '+str(e))
-                print e 
+    def tweetSentFinished(self):
+        self.tb_text.setEnabled(True)
+        self.tb_tweet.setEnabled(True)
+#Test of a threaded post from #Khweeteur 0.0.21
+
+    def tweet(self):
+        self.tb_text.setDisabled(True)
+        self.tb_tweet.setDisabled(True)
+        self.tweetAction = KhweeteurActionWorker(self,'tweet',unicode(self.tb_text.text()).encode('UTF-8'),self.tb_text_replyid,self.tb_text_replytext)
+        self.connect(self.tweetAction, SIGNAL("tweetSent()"), self.tweetSent)
+        self.connect(self.tweetAction, SIGNAL("finished()"), self.tweetSentFinished)
+        self.notifications.connect(self.tweetAction, SIGNAL('info(PyQt_PyObject)'), self.notifications.info)
+        self.notifications.connect(self.tweetAction, SIGNAL('warn(PyQt_PyObject)'), self.notifications.warn)
+        self.tweetAction.start()
+
+#        try:
+#                status_text = unicode(self.tb_text.text()).encode('UTF-8')
+#                if status_text.startswith(self.tb_text_replytext):
+#                    self.tb_text_replyid = 0
+#                    
+#                if self.settings.value("twitter_access_token_key").toString()!='':     
+#                    api = twitter.Api(
+#                                      username=KHWEETEUR_TWITTER_CONSUMER_KEY,password=KHWEETEUR_TWITTER_CONSUMER_SECRET, 
+#                                      access_token_key=str(self.settings.value("twitter_access_token_key").toString()),
+#                                      access_token_secret=str(self.settings.value("twitter_access_token_secret").toString()))
+#                    api.SetUserAgent('Khweeteur/%s' % (__version__))
+#                    if self.settings.value('useSerialization').toBool():
+#                        status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
+#                    else:
+#                        status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
+#                    self.notifications.info('Tweet send to Twitter')
+#
+#                if self.settings.value("identica_access_token_key").toString()!='':     
+#                    api = twitter.Api(base_url='http://identi.ca/api/',username=KHWEETEUR_IDENTICA_CONSUMER_KEY,
+#                                      password=KHWEETEUR_IDENTICA_CONSUMER_SECRET,
+#                                      access_token_key=str(self.settings.value("identica_access_token_key").toString()),
+#                                      access_token_secret=str(self.settings.value("identica_access_token_secret").toString()))
+#                    api.SetUserAgent('Khweeteur/%s' % (__version__))
+#                    if self.settings.value('useSerialization').toBool():
+#                        status = api.PostSerializedUpdates(status_text,in_reply_to_status_id=self.tb_text_replyid)
+#                    else:
+#                        status = api.PostUpdate(status_text,in_reply_to_status_id=self.tb_text_replyid)
+#                    self.notifications.info('Tweet send to Identica')
+#                    
+#                self.tb_text.setText('')
+#                self.tb_text_replyid = 0
+#                self.tb_text_replytext = ''
+#        except (twitter.TwitterError,StandardError),e:
+#            import traceback
+#            print traceback.print_exc()
+#            print traceback.print_stack()
+#            if type(e)==twitter.TwitterError:
+#                self.notifications.warn('Send tweet failed : '+(e.message))
+#                print e.message
+#            else:
+#                self.notifications.warn('Send tweet failed : '+str(e))
+#                print e 
 
     def refreshEnded(self):
 #        if self.search_keyword == None:
@@ -1069,7 +1158,7 @@ class KhweeteurWin(QMainWindow):
     def do_refresh_now(self):
         print type(self.settings.value('useNotification').toString()),self.settings.value('useNotification').toString()
         self.setAttribute(Qt.WA_Maemo5ShowProgressIndicator,True)
-        self.worker = KhweeteurWorker(search_keyword=self.search_keyword)
+        self.worker = KhweeteurWorker(self,search_keyword=self.search_keyword)
         self.connect(self.worker, SIGNAL("newStatuses(PyQt_PyObject)"), self.tweetsModel.addStatuses)
         self.connect(self.worker, SIGNAL("finished()"), self.refreshEnded)
         self.notifications.connect(self.worker, SIGNAL('info(PyQt_PyObject)'), self.notifications.info)
